@@ -135,8 +135,7 @@ createWindowList(PyObject* items)
         return NULL;
     }
 
-    CFMutableArrayRef array =
-        CFArrayCreateMutable(NULL, PyTuple_GET_SIZE(seq), NULL);
+    CFMutableArrayRef array = CFArrayCreateMutable(NULL, PyTuple_GET_SIZE(seq), NULL);
     if (array == NULL) {
         Py_DECREF(seq);
         PyErr_SetString(PyExc_ValueError, "Cannot create CFArray");
@@ -148,8 +147,7 @@ createWindowList(PyObject* items)
     for (i = 0; i < len; i++) {
         CGWindowID windowID;
 
-        if (PyObjC_PythonToObjC(@encode(CGWindowID), PyTuple_GET_ITEM(seq, i),
-                                &windowID)
+        if (PyObjC_PythonToObjC(@encode(CGWindowID), PyTuple_GET_ITEM(seq, i), &windowID)
             == -1) {
             Py_DECREF(seq);
             CFRelease(array);
@@ -204,7 +202,8 @@ m_CGWindowListCreateDescriptionFromArray(PyObject* self __attribute__((__unused_
     return rv;
 }
 
-#if !defined(MAC_OS_X_VERSION_15_0) || MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0
+#if !defined(MAC_OS_X_VERSION_15_0)                                                      \
+    || MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0
 static PyObject*
 m_CGWindowListCreateImageFromArray(PyObject* self __attribute__((__unused__)),
                                    PyObject* args)
@@ -265,7 +264,8 @@ m_CGWindowListCreateImageFromArray(PyObject* self __attribute__((__unused__)),
     CFRelease(image);
     return rv;
 }
-#endif /* defined(MAC_OS_X_VERSION_15_0) && MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0 */
+#endif /* defined(MAC_OS_X_VERSION_15_0) && MAC_OS_X_VERSION_MIN_REQUIRED <              \
+          MAC_OS_X_VERSION_15_0 */
 
 static PyObject*
 m_CGBitmapContextCreate(PyObject* self __attribute__((__unused__)), PyObject* args)
@@ -624,10 +624,12 @@ static PyMethodDef mod_methods[] = {
     {"CGWindowListCreate", (PyCFunction)m_CGWindowListCreate, METH_VARARGS, NULL},
     {"CGWindowListCreateDescriptionFromArray",
      (PyCFunction)m_CGWindowListCreateDescriptionFromArray, METH_VARARGS, NULL},
-#if !defined(MAC_OS_X_VERSION_15_0) || MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0
+#if !defined(MAC_OS_X_VERSION_15_0)                                                      \
+    || MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0
     {"CGWindowListCreateImageFromArray", (PyCFunction)m_CGWindowListCreateImageFromArray,
      METH_VARARGS, NULL},
-#endif /* !defined(MAC_OS_X_VERSION_15_0) || MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_15_0 */
+#endif /* !defined(MAC_OS_X_VERSION_15_0) || MAC_OS_X_VERSION_MIN_REQUIRED <             \
+          MAC_OS_X_VERSION_15_0 */
     {"CGBitmapContextCreate", (PyCFunction)m_CGBitmapContextCreate, METH_VARARGS, NULL},
     {"CGBitmapContextCreateWithData", (PyCFunction)m_CGBitmapContextCreateWithData,
      METH_VARARGS, NULL},
@@ -639,7 +641,8 @@ static PyMethodDef mod_methods[] = {
         0,
     }};
 
-static int mod_exec_module(PyObject* m)
+static int
+mod_exec_module(PyObject* m)
 {
     if (PyObjC_ImportAPI(m) < 0)
         return -1;
@@ -648,48 +651,44 @@ static int mod_exec_module(PyObject* m)
 }
 
 static struct PyModuleDef_Slot mod_slots[] = {
-    {
-        .slot = Py_mod_exec,
-        .value = (void*)mod_exec_module
-    },
+    {.slot = Py_mod_exec, .value = (void*)mod_exec_module},
 #if PY_VERSION_HEX >= 0x030c0000
     {
         /* This extension does not use the CPython API other than initializing
          * the module, hence is safe with subinterpreters and per-interpreter
          * GILs
          */
-        .slot = Py_mod_multiple_interpreters,
+        .slot  = Py_mod_multiple_interpreters,
         .value = Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED,
     },
 #endif
 #if PY_VERSION_HEX >= 0x030d0000
     {
         /* The code in this extension should be safe to use without the GIL */
-        .slot = Py_mod_gil,
+        .slot  = Py_mod_gil,
         .value = Py_MOD_GIL_NOT_USED,
     },
 #endif
-    {  /* Sentinel */
-        .slot = 0,
-        .value = 0
-    }
-};
+    {/* Sentinel */
+     .slot  = 0,
+     .value = 0}};
 
 static struct PyModuleDef mod_module = {
-    .m_base = PyModuleDef_HEAD_INIT,
-    .m_name = "_coregraphics",
-    .m_doc = NULL,
-    .m_size = 0,
-    .m_methods = mod_methods,
-    .m_slots = mod_slots,
+    .m_base     = PyModuleDef_HEAD_INIT,
+    .m_name     = "_coregraphics",
+    .m_doc      = NULL,
+    .m_size     = 0,
+    .m_methods  = mod_methods,
+    .m_slots    = mod_slots,
     .m_traverse = NULL,
-    .m_clear = NULL,
-    .m_free = NULL,
+    .m_clear    = NULL,
+    .m_free     = NULL,
 };
 
 PyObject* PyInit__coregraphics(void);
 
-PyObject* __attribute__((__visibility__("default"))) PyInit__coregraphics(void)
+PyObject* __attribute__((__visibility__("default")))
+PyInit__coregraphics(void)
 {
     return PyModuleDef_Init(&mod_module);
 }
